import markdown
import os
import json
import errno
import ZypeSDK as z
import sys


def compile():
    file = sys.argv[1]
    cType = sys.argv[2]
    to = sys.argv[3]
    if cType == 'md' and to == 'html':
        if os.path.isfile(file):
            with open(file, 'r') as md:
                text = md.read()
                html = markdown.markdown(text)
                html = f"""<!DOCTYPE html>
    <html>
    <head>
    <title>ZypeC Generated HTML</title>

        <meta charset="utf-8" />
        <meta http-equiv="Content-type" content="text/html; charset=utf-8" />
        <meta name="viewport" content="width=device-width, initial-scale=1" />
        <link href="https://raw.githubusercontent.com/Zype-Z/ZypeC/main/assets/favicon.png" rel="icon">
    </head>

    <body>
    {html}
    </body>
    </html>"""
                hfile = file.replace('.md', '.html')
                with open(f'{hfile}', 'w') as fh:
                    fh.write(html)
        else:
            raise FileNotFoundError(
                errno.ENOENT, os.strerror(errno.ENOENT), file)
    elif cType == 'zype' and to == 'json':
        ZypeFile = z.Open(file)
        JSONFile = file.replace('.zype', '.json')
        with open(f'{JSONFile}', 'w') as JSON:
            JSON.write(ZypeFile)
    else:
        raise ValueError(f"Zype: {cType} is not supported")

if __name__ == "__main__":
    print("Can't be used without CLI.")



from ZypeC.compilers import compile
import sys
import os
import platform
from rich import print

def cli():
    if sys.argv[1] == '--version' or sys.argv[1] == '-v':
        print("[bold red]Zype[/bold red]: v1.2.0")
    else:
        compile()


import setuptools
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
setuptools.setup(
    name="ZypeC",
    version="1.2.0",
    author="TechGeeks",
    author_email="ZypeC@tgeeks.cf",
    maintainer="Rajdeep Malakar",
    maintainer_email="Rajdeep@tgeeks.cf",
    description="Zype Compilers",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Zype-Z/ZypeC",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
        'markdown',
        'ZypeSDK'
    ],
    entry_points=dict(
        console_scripts=['zype=ZypeC.cli:cli']
    )
)